TokenResolverChanged class final

A design token's resolver (theme-binding path) changed. Additive — existing blobs see the new resolved value at render time.

Inheritance
Annotations
  • @experimental

Constructors

TokenResolverChanged({required WireIdRef affected})
Creates a token-resolver change.
const

Properties

affected → WireIdRef
(library, wireId) reference to the affected entry.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
kind → WireIdKind
Wire-ID kind of the affected entry.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited