StabilityPolicy class final
Stability-tier rules for catalog entries.
- Annotations
-
- @immutable
Constructors
- StabilityPolicy({required Stability defaultTier, required bool annotationPromotion})
-
Creates a stability policy.
const
Properties
- annotationPromotion → bool
-
Honor
@StableProperty/@StableWidgetannotations.final - defaultTier → Stability
-
Stability.volatilefor auto-walked entries;Stability.stablerequires opt-in.final - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
extend(
{Stability? defaultTier, bool? annotationPromotion}) → StabilityPolicy - Returns a new policy with the supplied overrides applied.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override