UnionMemberRemoved class final
A member structured type was removed from a union. Breaking — blobs carrying that discriminator value fail.
- Inheritance
-
- Object
- CatalogChange
- UnionMemberRemoved
- Annotations
-
- @experimental
Constructors
- UnionMemberRemoved({required WireIdRef affected, required WireIdRef member})
-
Creates a union-member-removed change for
member.const
Properties
- affected → WireIdRef
-
(library, wireId)reference to the affected entry.finalinherited - hashCode → int
-
The hash code for this object.
no setteroverride
- kind → WireIdKind
-
Wire-ID kind of the affected entry.
finalinherited
- member → WireIdRef
-
The structured member removed from the union.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override